Struct modularity::UnresolvedPackage
source · pub struct UnresolvedPackage { /* private fields */ }Expand description
Denotes a package that must be supplied for resolution to continue.
Implementations
sourceimpl UnresolvedPackage
impl UnresolvedPackage
sourcepub fn id(&self) -> &PackageIdentifier
pub fn id(&self) -> &PackageIdentifier
Gets the requested ID of this package.
sourcepub fn exact(&self) -> bool
pub fn exact(&self) -> bool
Whether the resolved component must match in version exactly. Otherwise, any version
that is greater only in patch (satisfying the semver equation actual = ^requested)
is allowed.
sourcepub fn is_resolved(&self) -> bool
pub fn is_resolved(&self) -> bool
Whether a component has been provided for this package.
sourcepub fn resolve(&mut self, id: PackageIdentifier, component: Component)
pub fn resolve(&mut self, id: PackageIdentifier, component: Component)
Resolves this package using the given component and ID. The resolved component must match in name and have a compatible version, otherwise, a panic will occur.